@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA. */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+   USA. */
 
 #include <stdarg.h>
 #include <stdio.h>
@@ -984,11 +984,11 @@ read_value_label (struct file_handle *h)
 	{
 	  struct variable *var = v[j];
 	  struct value_label *old;
+	  int width = var->width;
 
 	  /* Create AVL tree if necessary. */
 	  if (!var->val_lab)
-	    var->val_lab = avl_create (val_lab_cmp,
-				       (void *) (var->width));
+	    var->val_lab = avl_create (val_lab_cmp, (void *) &width);
 
 	  old = avl_replace (var->val_lab, vl);
 	  if (old == NULL)
